@@ -7,17 +7,15 @@ from typing import List
 from python_search.apps.notification_ui import send_notification
 from python_search.config import PythonSearchConfiguration
 from python_search.context import Context
-from python_search.events.search_run_performed import SearchRunPerformed, LogSearchRunPerformed
+from python_search.events.run_performed import (RunPerformed)
+from python_search.events.run_performed.client import LogRunPerformedClient
 from python_search.interpreter.cmd import CmdInterpreter
 from python_search.interpreter.interpreter_matcher import InterpreterMatcher
-from python_search.observability.logger import (initialize_systemd_logging,
-                                                logging)
-
 from python_search.logger import setup_run_key_logger
 
-
 logger = setup_run_key_logger()
 
+
 class EntryRunner:
     """
     Responsible to execute the _entries matched
@@ -25,7 +23,6 @@ class EntryRunner:
 
     def __init__(self, configuration: PythonSearchConfiguration):
         self.configuration = configuration
-        self.logging = initialize_systemd_logging()
 
     def run(
         self,
@@ -44,14 +41,13 @@ class EntryRunner:
             from_shortcut means that the key execution was triggered by a desktop shortcut
         """
 
-        
         logger.info("Arrived at run key")
         # if there are : in the line just take all before it as it is
         # usually the key from fzf, and our keys do not accept :
         metadata = ""
         if ":" in key:
             key, metadata = key.split(":", 1)
-            self.logging.info(f"metadata: {metadata}")
+            logger.info(f"metadata: {metadata}")
 
         if from_shortcut:
             send_notification(f"{key}")
@@ -63,7 +59,7 @@ class EntryRunner:
                 matadata_dict = json.loads(metadata)
                 rank_position = matadata_dict.get("position")
             except BaseException as e:
-                self.logging.warning(f"Could not decode metadata: {e}")
+                logger.warning(f"Could not decode metadata: {e}")
 
         # when there are no matches we actually will use the query and interpret it
         if not key and query_used:
@@ -75,7 +71,7 @@ class EntryRunner:
         if not matches:
             raise Exception(f"No key matches you given requested key: {key}")
 
-        self.logging.info(
+        logger.info(
             f"""
             Matches of key: {key}
             matches: {matches}
@@ -87,7 +83,6 @@ class EntryRunner:
         if force_gui_mode or gui_mode:
             Context.get_instance().enable_gui_mode()
 
-
         real_key: str = matches[0]
 
         if len(matches) > 1:
@@ -96,12 +91,12 @@ class EntryRunner:
                 f"Multiple matches for this key {matches} using the smaller"
             )
 
-        LogSearchRunPerformed().send(SearchRunPerformed(key=key, query_input=query_used, shortcut=from_shortcut))
-
-        return InterpreterMatcher.build_instance(self.configuration).default(real_key)
-
-
+        result = InterpreterMatcher.build_instance(self.configuration).default(real_key)
 
+        LogRunPerformedClient().send(
+            RunPerformed(key=key, query_input=query_used, shortcut=from_shortcut)
+        )
+        return result
 
     def _matching_keys(self, key: str) -> List[str]:
         """
@@ -116,7 +111,7 @@ class EntryRunner:
             encoded_registered_key = generate_identifier(registered_key)
             matches_kv_encoded = key_regex.search(encoded_registered_key)
             if matches_kv_encoded:
-                logging.info(f"{key} matches {encoded_registered_key}")
+                logger.info(f"{key} matches {encoded_registered_key}")
                 matching_keys.append(registered_key)
 
         return matching_keys
