@@ -1,9 +1,8 @@
 from fastapi import FastAPI
 from fastapi.responses import PlainTextResponse
 
-from python_search.data_collector import GenericDataCollector
-from python_search.events.search_run_performed import SearchRunPerformed
 from python_search.events.latest_used_entries import RecentKeys
+from python_search.events.run_performed import RunPerformed, RunPerformedWriter
 
 PORT = 8000
 
@@ -54,18 +53,19 @@ def health():
     }
 
 
-
 @app.post("/log_run")
-def log_run(event: SearchRunPerformed):
+def log_run(event: RunPerformed):
 
     RecentKeys.add_latest_used(event.key)
-    GenericDataCollector().write(data=event.__dict__, table_name='searches_performed')
+
+    RunPerformedWriter().write(event)
 
     # regenerate the ranking after running a key
     reload()
 
     return event
 
+
 @app.get("/recent_history")
 def recent_history_endpoint():
     return RecentKeys().get_latest_used_keys()
@@ -76,7 +76,7 @@ def main():
 
     import uvicorn
 
-    os.putenv("WEB_CONCURRENCY", "1")
+    os.putenv("WEB_CONCURRENCY", "0")
     reload = False
     if "PS_DEBUG" in os.environ:
         print("Debug mode is ON, enabling reload")
